@@ -91,16 +91,24 @@ def run_chain(*tasks: Task, run_all: bool = False) -> bool:
             )
             cwd = task.output_folder / task.task_folder.name
             batch_name = next(cwd.glob('batch.*'))
-            try:
-                subprocess.run(  # noqa: S603
-                    [Path.cwd() / batch_name],
-                    cwd=cwd,
-                    check=True,
+            proc = subprocess.Popen(  # noqa: S603
+                [Path.cwd() / batch_name],
+                cwd=cwd,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+            )
+            buffer = b''
+            for c in iter(lambda: proc.stdout.read(1), b''):  # pyright: ignore[reportOptionalMemberAccess]  # noqa: B023
+                if c != b'\n':
+                    buffer += c
+                else:
+                    logger.info('[SUBPROCESS] %s', buffer.decode())
+                    buffer = b''
+            logger.info('[SUBPROCESS] %s', buffer.decode())
+            logger.exception('Error submitting job, see output above.')
+            if proc.returncode != 0:
+                raise subprocess.CalledProcessError(
+                    proc.returncode, Path.cwd() / batch_name
                 )
-            except subprocess.CalledProcessError as e:
-                logger.exception(
-                    'Error submitting job, see output above.', extra={'error': e}
-                )
-                raise
             previous_ran = True
     return previous_ran
